@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class AlipayEbppIndustryAntforestEventSendModel(object):
 
     def __init__(self):
+        self._open_id = None
         self._type = None
         self._user_id = None
 
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def type(self):
         return self._type
 
@@ -29,6 +37,11 @@ class AlipayEbppIndustryAntforestEventSendModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.type:
             if hasattr(self.type, 'to_alipay_dict'):
                 params['type'] = self.type.to_alipay_dict()
@@ -46,6 +59,8 @@ class AlipayEbppIndustryAntforestEventSendModel(object):
         if not d:
             return None
         o = AlipayEbppIndustryAntforestEventSendModel()
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'type' in d:
             o.type = d['type']
         if 'user_id' in d:
