@@ -13,6 +13,7 @@ class AlipayFundJointaccountFundOrderQueryModel(object):
         self._biz_scene = None
         self._biz_trans_id = None
         self._channel = None
+        self._open_id = None
         self._operate_type = None
         self._out_biz_no = None
         self._product_code = None
@@ -54,6 +55,13 @@ class AlipayFundJointaccountFundOrderQueryModel(object):
     def channel(self, value):
         self._channel = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def operate_type(self):
         return self._operate_type
 
@@ -110,6 +118,11 @@ class AlipayFundJointaccountFundOrderQueryModel(object):
                 params['channel'] = self.channel.to_alipay_dict()
             else:
                 params['channel'] = self.channel
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.operate_type:
             if hasattr(self.operate_type, 'to_alipay_dict'):
                 params['operate_type'] = self.operate_type.to_alipay_dict()
@@ -147,6 +160,8 @@ class AlipayFundJointaccountFundOrderQueryModel(object):
             o.biz_trans_id = d['biz_trans_id']
         if 'channel' in d:
             o.channel = d['channel']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'operate_type' in d:
             o.operate_type = d['operate_type']
         if 'out_biz_no' in d:
