@@ -9,6 +9,7 @@ class AlipayMarketingActivityVoucherPublishModel(object):
 
     def __init__(self):
         self._activity_id = None
+        self._merchant_access_mode = None
         self._out_biz_no = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayMarketingActivityVoucherPublishModel(object):
     def activity_id(self, value):
         self._activity_id = value
     @property
+    def merchant_access_mode(self):
+        return self._merchant_access_mode
+
+    @merchant_access_mode.setter
+    def merchant_access_mode(self, value):
+        self._merchant_access_mode = value
+    @property
     def out_biz_no(self):
         return self._out_biz_no
 
@@ -34,6 +42,11 @@ class AlipayMarketingActivityVoucherPublishModel(object):
                 params['activity_id'] = self.activity_id.to_alipay_dict()
             else:
                 params['activity_id'] = self.activity_id
+        if self.merchant_access_mode:
+            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
+                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
+            else:
+                params['merchant_access_mode'] = self.merchant_access_mode
         if self.out_biz_no:
             if hasattr(self.out_biz_no, 'to_alipay_dict'):
                 params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayMarketingActivityVoucherPublishModel(object):
         o = AlipayMarketingActivityVoucherPublishModel()
         if 'activity_id' in d:
             o.activity_id = d['activity_id']
+        if 'merchant_access_mode' in d:
+            o.merchant_access_mode = d['merchant_access_mode']
         if 'out_biz_no' in d:
             o.out_biz_no = d['out_biz_no']
         return o
