@@ -10,8 +10,10 @@ from alipay.aop.api.domain.WeightFloor import WeightFloor
 class AlipayMsaasMediarecogAftscvpayTransactionInitializeModel(object):
 
     def __init__(self):
+        self._device_identify_type = None
         self._goods_infos = None
         self._machine_type = None
+        self._open_id = None
         self._scene = None
         self._terminal_id = None
         self._total_floors = None
@@ -21,6 +23,13 @@ class AlipayMsaasMediarecogAftscvpayTransactionInitializeModel(object):
         self._weight_template = None
 
     @property
+    def device_identify_type(self):
+        return self._device_identify_type
+
+    @device_identify_type.setter
+    def device_identify_type(self, value):
+        self._device_identify_type = value
+    @property
     def goods_infos(self):
         return self._goods_infos
 
@@ -41,6 +50,13 @@ class AlipayMsaasMediarecogAftscvpayTransactionInitializeModel(object):
     def machine_type(self, value):
         self._machine_type = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def scene(self):
         return self._scene
 
@@ -99,6 +115,11 @@ class AlipayMsaasMediarecogAftscvpayTransactionInitializeModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.device_identify_type:
+            if hasattr(self.device_identify_type, 'to_alipay_dict'):
+                params['device_identify_type'] = self.device_identify_type.to_alipay_dict()
+            else:
+                params['device_identify_type'] = self.device_identify_type
         if self.goods_infos:
             if isinstance(self.goods_infos, list):
                 for i in range(0, len(self.goods_infos)):
@@ -114,6 +135,11 @@ class AlipayMsaasMediarecogAftscvpayTransactionInitializeModel(object):
                 params['machine_type'] = self.machine_type.to_alipay_dict()
             else:
                 params['machine_type'] = self.machine_type
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.scene:
             if hasattr(self.scene, 'to_alipay_dict'):
                 params['scene'] = self.scene.to_alipay_dict()
@@ -161,10 +187,14 @@ class AlipayMsaasMediarecogAftscvpayTransactionInitializeModel(object):
         if not d:
             return None
         o = AlipayMsaasMediarecogAftscvpayTransactionInitializeModel()
+        if 'device_identify_type' in d:
+            o.device_identify_type = d['device_identify_type']
         if 'goods_infos' in d:
             o.goods_infos = d['goods_infos']
         if 'machine_type' in d:
             o.machine_type = d['machine_type']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'scene' in d:
             o.scene = d['scene']
         if 'terminal_id' in d:
