@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class MybankCreditLoanapplyElmCreditloanadmitQueryModel(object):
 
     def __init__(self):
+        self._open_id = None
         self._site = None
         self._site_user_id = None
 
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def site(self):
         return self._site
 
@@ -29,6 +37,11 @@ class MybankCreditLoanapplyElmCreditloanadmitQueryModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.site:
             if hasattr(self.site, 'to_alipay_dict'):
                 params['site'] = self.site.to_alipay_dict()
@@ -46,6 +59,8 @@ class MybankCreditLoanapplyElmCreditloanadmitQueryModel(object):
         if not d:
             return None
         o = MybankCreditLoanapplyElmCreditloanadmitQueryModel()
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'site' in d:
             o.site = d['site']
         if 'site_user_id' in d:
