@@ -52,6 +52,7 @@ class AlipayUserInfoShareResponse(AlipayResponse):
         self._inst_or_corp = None
         self._is_adult = None
         self._is_balance_frozen = None
+        self._is_blocked = None
         self._is_certified = None
         self._is_student_certified = None
         self._license_expiry_date = None
@@ -59,10 +60,12 @@ class AlipayUserInfoShareResponse(AlipayResponse):
         self._member_grade = None
         self._mobile = None
         self._nick_name = None
+        self._open_id = None
         self._organization_code = None
         self._person_birthday = None
         self._person_birthday_without_year = None
         self._person_cert_expiry_date = None
+        self._person_cert_issue_date = None
         self._person_pictures = None
         self._phone = None
         self._profession = None
@@ -367,6 +370,13 @@ class AlipayUserInfoShareResponse(AlipayResponse):
     def is_balance_frozen(self, value):
         self._is_balance_frozen = value
     @property
+    def is_blocked(self):
+        return self._is_blocked
+
+    @is_blocked.setter
+    def is_blocked(self, value):
+        self._is_blocked = value
+    @property
     def is_certified(self):
         return self._is_certified
 
@@ -416,6 +426,13 @@ class AlipayUserInfoShareResponse(AlipayResponse):
     def nick_name(self, value):
         self._nick_name = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def organization_code(self):
         return self._organization_code
 
@@ -444,6 +461,13 @@ class AlipayUserInfoShareResponse(AlipayResponse):
     def person_cert_expiry_date(self, value):
         self._person_cert_expiry_date = value
     @property
+    def person_cert_issue_date(self):
+        return self._person_cert_issue_date
+
+    @person_cert_issue_date.setter
+    def person_cert_issue_date(self, value):
+        self._person_cert_issue_date = value
+    @property
     def person_pictures(self):
         return self._person_pictures
 
@@ -607,6 +631,8 @@ class AlipayUserInfoShareResponse(AlipayResponse):
             self.is_adult = response['is_adult']
         if 'is_balance_frozen' in response:
             self.is_balance_frozen = response['is_balance_frozen']
+        if 'is_blocked' in response:
+            self.is_blocked = response['is_blocked']
         if 'is_certified' in response:
             self.is_certified = response['is_certified']
         if 'is_student_certified' in response:
@@ -621,6 +647,8 @@ class AlipayUserInfoShareResponse(AlipayResponse):
             self.mobile = response['mobile']
         if 'nick_name' in response:
             self.nick_name = response['nick_name']
+        if 'open_id' in response:
+            self.open_id = response['open_id']
         if 'organization_code' in response:
             self.organization_code = response['organization_code']
         if 'person_birthday' in response:
@@ -629,6 +657,8 @@ class AlipayUserInfoShareResponse(AlipayResponse):
             self.person_birthday_without_year = response['person_birthday_without_year']
         if 'person_cert_expiry_date' in response:
             self.person_cert_expiry_date = response['person_cert_expiry_date']
+        if 'person_cert_issue_date' in response:
+            self.person_cert_issue_date = response['person_cert_issue_date']
         if 'person_pictures' in response:
             self.person_pictures = response['person_pictures']
         if 'phone' in response:
